//******************************************************************************
//*                                  uBee512                                   *
//*         An emulator for the Microbee Z80 FDD and ROM based models          *
//*                                                                            *
//*                               clock module                                *
//*                                                                            *
//*                       Copyright (C) 2007 Stewart Kay                       *
//******************************************************************************
//
// Change CPU clock speed.
//
//==============================================================================
// ChangeLog (most recent entries are at top)
//==============================================================================
// v2.1.0 - 19 October 2007, S.J.Kay
// - Created a new file and implement the CPU clock speed change code.

//==============================================================================
/*
 *  uBee512 - An emulator for the Microbee Z80 FDD and ROM based models. 
 *  Copyright (C) 2007  Stewart Kay
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
//==============================================================================

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "clock.h"
#include "ubee512.h"
#include "z80.h"
#include "mz80.h"

#include "macros.h"

//==============================================================================
// structures and variables
//==============================================================================
static int clock_changed;

extern model_t modelx;

extern int cpuclock;

extern FILE *debuglog;
extern int debuglvl;

//==============================================================================
// Clock Initialise.
//
//   pass: void
// return: int				0
//==============================================================================
int clock_init (void)
{
 return 0;
}

//==============================================================================
// Clock  de-initialise
//
//   pass: void
// return: int				0
//==============================================================================
int clock_deinit (void)
{
 return 0;
}

//==============================================================================
// Clock reset
//
// Set the clock speed back to normal
//
//   pass: void
// return: int				0
//==============================================================================
int clock_reset (void)
{
 if ((modelx.speed) && (clock_changed))
    {
     set_clock_speed(3.375);
     clock_changed = 0;
    } 
 return 0;
}

//==============================================================================
// Clock speed change - Port function
//
//   pass: UINT16 port
//         struct z80PortRead *port_s
// return: UINT16			0xFFFF
//==============================================================================
UINT16 clock_r (UINT16 port, struct z80PortRead *port_s)
{
 struct mz80context z80;
 uint8_t opcode;
 int clock;

 if (modelx.speed)
    {
     mz80GetContext(&z80);    

     opcode = (uint8_t)z80mem[z80.z80pc - 2];     
     if (opcode == 0xdb)

// MZ80 has endian problem, work around for now
//      bank = z80.z80af.half.a & bank_mask;
        clock = (int)z80.z80af.af & B8(00000011);
     else
//      bank = z80.z80bc.half.b & bank_mask;
        clock = ((int)z80.z80bc.bc >> 8) & B8(00000011);

//     printf("clock_r: clock=0x%02X\n", clock);

// only change the speed if it needs it.
     if ((cpuclock == 3375000) && (clock == B8(00000010)))
        {
         set_clock_speed(6.750);
         clock_changed = 1;
        } 
     else
        {
         if ((cpuclock == 6750000) && (clock == B8(00000000)))
            {
             set_clock_speed(3.375);
             clock_changed = 1;
            }
        }     
     return clock;
    }       
 return 0;
}
