/* FDC Header */

#ifndef HEADER_FDC_H
#define HEADER_FDC_H

#include "disk.h"
#include "mz80.h"

#define FDC_NUMDRIVES    4

#define FDC_RESTORE      0       /* type I */
#define FDC_SEEK         1
#define FDC_STEP         2
#define FDC_STEPIN       4
#define FDC_STEPOUT      6

#define FDC_READSECT     8       /* type II */
#define FDC_WRITESECT    10

#define FDC_READADDR     12      /* type III */
#define FDC_READTRACK    14
#define FDC_WRITETRACK   15

#define FDC_INTERRUPT    13      /* type IV */


#define FDC_NOTREADY     0x80    /* status port bits */
#define FDC_WRPROT       0x40
#define FDC_HEADLOADED   0x20
#define FDC_RECTYPE      0x20
#define FDC_SEEKERROR    0x10
#define FDC_RECNOTFOUND  0x10
#define FDC_CRCERROR     0x08
#define FDC_TRACK0       0x04
#define FDC_LOSTDATA     0x04
#define FDC_INDEXPULSE   0x02
#define FDC_DRQ          0x02
#define FDC_BUSY         0x01

#define FDC_STEPRATE     0x03    /* fdc command data bits */
#define FDC_VERIFY       0x04
#define FDC_LOADHEAD     0x08
#define FDC_UPDATETRACK  0x10
#define FDC_MULTISECT    0x10
#define FDC_SIDE         0x08
#define FDC_DELAY        0x04
#define FDC_CMPSIDE      0x02
#define FDC_DATAMARK     0x01
#define FDC_INTREADY     0x01
#define FDC_INTNOTREADY  0x02
#define FDC_INTINDEX     0x04
#define FDC_INTIMMED     0x08

#define FDC_MAXTRACK     255

#define FDC_BUFSIZE      1024*10	// maximum data per track HD Floppy

int fdc_init (void);
int fdc_deinit (void);
int fdc_reset (void);

UINT16 fdc_status (UINT16 port, struct z80PortRead *port_s);
void fdc_cmd (UINT16 port, UINT8 data, struct z80PortWrite *port_s);

UINT16 fdc_data_r (UINT16 port, struct z80PortRead *port_s);
void fdc_data_w (UINT16 port, UINT8 data, struct z80PortWrite *port_s);
UINT16 fdc_track_r (UINT16 port, struct z80PortRead *port_s);
void fdc_track_w (UINT16 port, UINT8 data, struct z80PortWrite *port_s);
UINT16 fdc_sect_r (UINT16 port, struct z80PortRead *port_s);
void fdc_sect_w (UINT16 port, UINT8 data, struct z80PortWrite *port_s);

UINT16 fdc_ext_r (UINT16 port, struct z80PortRead *port_s);
void fdc_ext_w (UINT16 port, UINT8 data, struct z80PortWrite *port_s);

struct fdc_drive_s
{
 int track;                          	// current track position of the head
 disk_t *disk;
};

typedef struct fdc_drive_s fdc_drive_t;

#endif  /* HEADER_FDC_H */
