//******************************************************************************
//*                                  uBee512                                   *
//*         An emulator for the Microbee Z80 FDD and ROM based models          *
//*                                                                            *
//*                              Keyboard module                               *
//*                                                                            *
//*                       Copyright (C) 2007 Stewart Kay                       *
//******************************************************************************
//
// Overhead keyboard code for the CRTC6545 and 256TC keyboard encoders.
// The 256TC model uses both encoder modules.
//
//==============================================================================
// ChangeLog (most recent entries are at top)
//==============================================================================
// v2.0.0 - 14 October 2007, S.J.Kay
// - Code specific for standard keyboard (CRT6545) has been moved to
//   keystd.c, this module is now simply used as an overhead to call
//   functions in keystd.c and keytc.c modules.
// - Moved revision history to stdkey.c as it directly relates to that module.
//
// v0.0.0 - 11 June 2007, S.J.Kay
// Start with "nanowasp" source distribution version 0.22. An emulator for the
// microbee 128k. Copyright (C) 2000-2003  David G. Churchill.

//==============================================================================
/*
 *  uBee512 - An emulator for the Microbee Z80 FDD and ROM based models. 
 *  Copyright (C) 2007  Stewart Kay
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
//==============================================================================

#include <stdio.h>
#include <stdlib.h>

#include "keyb.h"
#include "keystd.h"
#include "keytc.h"
#include "ubee512.h"

extern int model;

extern FILE *debuglog;
extern int debuglvl;

//==============================================================================
// Keyboard initialise
//
//   pass: void
// return: int 				0
//==============================================================================
int keyb_init (void)
{
 if (model == MOD_256TC)
    return keytc_init() | keystd_init();
 else
    return keystd_init();
}

//==============================================================================
// Keyboard de-initialise
//
//   pass: void
// return: int 				0
//==============================================================================
int keyb_deinit (void)
{
 if (model == MOD_256TC)
    return keytc_deinit() | keystd_deinit();
 else
    return keystd_deinit();
}

//==============================================================================
// Keyboard reset
//
//   pass: void
// return: int 				0
//==============================================================================
int keyb_reset (void)
{
 if (model == MOD_256TC)
    return keytc_reset() | keystd_reset();
 else
    return keystd_reset();
}

//==============================================================================
// key down event handler.
//
// This creates the Microbee scan keys and determines what inverting action
// may be required for each Microbee key generated.
//
//   pass: void
// return: void
//==============================================================================
void keyb_keydown_event (void)
{
 if (model == MOD_256TC)
    {
     keytc_keydown_event();
     keystd_keydown_event();
    } 
 else
    keystd_keydown_event();
}         

//==============================================================================
// key up event handler.
//
// This creates the Microbee scan keys and determines what inverting action
// may be required for each Microbee key generated.
//
//   pass: void
// return: void
//==============================================================================
void keyb_keyup_event (void)
{
 if (model == MOD_256TC)
   {
    keytc_keyup_event();
    keystd_keyup_event();
   } 
 else
    keystd_keyup_event();
}

//==============================================================================
// Force a character to be returned.
//
// This is useful for placing the boot code into monitor mode by forcing the 'M'
// key (0x0d) to be returned or for pasting.
//
//   pass: int scan			scan code 0-63
//   pass: int counts			number of times to be forced
// return: void
//==============================================================================
void keyb_force (int scan, int counts)
{
 if (model == MOD_256TC)
    keytc_force(scan, counts);
 else
    keystd_force(scan, counts);
}    

//==============================================================================
// Force none.
//
// Forces no scan matches for counts
//
//   pass: int counts			number of times to be forced
// return: void
//==============================================================================
void keyb_force_none (int counts)
{
 if (model == MOD_256TC)
    keytc_force_none(counts);
 else
    keystd_force_none(counts);
}    
